This part of the documentation provides automatically generated information about RDFProxy symbols.

---
::: rdfproxy.adapter.SPARQLModelAdapter
---
::: rdfproxy.constructor._PageQueryConstructor
---
::: rdfproxy.mapper._ModelBindingsMapper
---


---
::: rdfproxy.utils._types.ConfigDict
---
::: rdfproxy.utils._types.SPARQLBinding
---


---
::: rdfproxy.utils.models.Page
---
::: rdfproxy.utils.models.QueryParameters
---
